@@ -350,7 +350,9 @@ def _fit(name: str = Argument(..., help='Project name.'),
                                                                                   ' the right (except for cases when such an expansion is not'
                                                                                   ' possible but the minimal slice or window size requirement is not '
                                                                                   'met).'),
-         min_slices: int = Option(1, help='Minimal number of slices per window.'),
+         min_slices: int = Option(3, help='Minimal number of slices per window.'),
+         stop_slice_n: int = Option(10, help='Parameters are estimated as long as windows center slice has more than [cyan]stop-slice-n[/cyan]'
+                                              ' number of samples.'),
          adjust_line: bool = Option(False, help='Line parameter beta and mu will be reestimated without a loss of likelihood so they differ'
                                                 ' as little as possible from the previous b and mu estimates.'),
          k_left_bound: int = Option(1, help='Minimal allowed value for concentration parameter [italic]k[/italic].'),
@@ -377,8 +379,8 @@ def _fit(name: str = Argument(..., help='Project name.'),
                                                       '[red]r[/red] itself.'),
          symmetrify: bool = Option(False, help='Symmetrifies count data before fitting model to it. Might be helpful in cases when you know'
                                                 ' that ref|alt model should be equal to alt|ref, e.g. when fitting the model to post-WASP data.'),
-         small_dataset_n: int = Option(1000, help='If a number of observations at BAD is below this threshold, [yellow]small_dataset_strategy[/yellow]'
-                                                  ' will be applied.'),
+         small_dataset_n: int = Option(10000, help='If a number of observations at BAD is below this threshold, [yellow]small_dataset_strategy[/yellow]'
+                                                   ' will be applied.'),
          small_dataset_strategy: SmallDatasetStrategy = Option('conservative', help='[yellow]fixed_r[/yellow] constraints r as it is constrained in'
                                                                                     ' [yellow]conservative[/yellow] mode.'),
          n_jobs: int = Option(-1, help='Number of jobs to be run at parallel, -1 will use all available threads.'),
@@ -417,7 +419,8 @@ def _fit(name: str = Argument(..., help='Project name.'),
         max_count=max_count, max_cover=max_cover, adjusted_loglik=adjusted_loglik, n_jobs=n_jobs, start_est=start_est,
         apply_weights=apply_weights, regul_alpha=regul_alpha, regul_n=regul_n, regul_slice=regul_slice, regul_prior=regul_prior,
         fix_params=fix_params, std=std, optimizer=optimizer, r_transform=None if r_transform == 'none' else r_transform,
-        symmetrify=symmetrify, small_dataset_strategy=small_dataset_strategy, small_dataset_n=small_dataset_n)
+        symmetrify=symmetrify, small_dataset_strategy=small_dataset_strategy, small_dataset_n=small_dataset_n,
+        stop_slice_n=stop_slice_n)
     if pretty:
         p.stop()
     update_history(name, 'fit', dist=dist, model=model, left=left, estimate_p=estimate_p, window_size=window_size, 
@@ -425,7 +428,7 @@ def _fit(name: str = Argument(..., help='Project name.'),
                    max_count=max_count, max_cover=max_cover, adjusted_loglik=adjusted_loglik, n_jobs=n_jobs, 
                    regul_alpha=regul_alpha, regul_n=regul_n, regul_slice=regul_slice, regul_prior=regul_prior,
                    fix_params=fix_params, std=std, optimizer=optimizer, r_transform=r_transform, symmetrify=symmetrify,
-                   small_dataset_strategy=small_dataset_strategy, small_dataset_n=small_dataset_n)
+                   small_dataset_strategy=small_dataset_strategy, small_dataset_n=small_dataset_n, stop_slice_n=stop_slice_n)
     dt = time() - t0
     if pretty:
         rprint(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
